{% extends 'portal/base.html' %}
{% load static %}
{% load app_tags %}

{% block content %}

<div class="form--register form--register--teacher is-flex">
    <div class="col-xs-12 col-sm-8 col-md-6 col-lg-4 center-block">
        <h4>Invitation sent</h4>
        <img class="background" title="Paper Plane" alt="Verification email sent" src="{% static 'portal/img/paper_plane.png' %}">
        <p>Your invitation is on its way. You will receive a notification on your dashboard once a teacher has
            requested to join your school or club.</p>
        <a href="{% url 'dashboard' %}">OK</a>
    </div>
</div>

{% endblock content %}
