{# Overriden the original "two_factor" template to direct us somewhere more sensible #}

{% extends "two_factor/_base_focus.html" %}
{% load i18n future %}

{% block content %}
<h4 class="text-center">{% block title %}{% trans "Two-factor authentication set up complete" %}{% endblock %}</h4>

<p>{% blocktrans %}You have successfully set up 2FA. &#127881;{% endblocktrans %}</p>
<p>{% blocktrans %}You will now need to use your code generator the next time you log in.{% endblocktrans %}</p>

<p><a href="{% url 'dashboard' %}" class="button button--primary">{% trans "OK" %}</a></p>
{% endblock %}
