{% extends 'portal/form_shapes.html' %}
{% load static %}

{% block form_content %}
<div id="reset_password_email_sent_page"></div>
<h4>Thank you</h4>
<h5>If you have entered a valid email address, you will receive a link to
    reset your password. Make sure to check your <strong>spam</strong>.</h5>
<img class="background" title="Paper Plane" alt="Verification email sent"
    src="{% static 'portal/img/paper_plane.png' %}">
<div>
    <a target="_blank"
        href="https://mail.google.com/mail/#search/from%3Ano-reply%40info.codeforlife.education+subject%3APassword+reset+request"
        class="button button--home button-email">Open in Gmail</a>
    <a target="_blank" href="https://outlook.live.com/mail/" class="button button--home button-email">Open in
        Outlook</a>
</div>
<p class="text-left"><a id="home_button" href="{% url 'home' %}">&lt; back to homepage</a></p>
{% endblock form_content %}