{% extends 'portal/base.html' %}
{% load static %}
{% load app_tags %}
{% load banner_tags %}

{% block content %}


{% banner banner_name="BANNER" %}


<div class="background container">
    <section>
        <h4>Who are the club packs aimed at?</h4>
    </section>
    <div class="row">
        <div class="col-sm-12">
            <p>
                The FREE resource packs are aimed at two different groups, the first is aimed at students ages
                    between 7-11yrs with an interest in learning Python. The second pack is aimed at students 12yrs
                    and up, including adults. This moves at a much faster pace and also introduces students to
                    setting up an environment on their own computer.
            </p>
            <p>
                Both packs are a condensed learning pathway using our game Rapid Router alongside suggested
                session plan and slides.
            </p>
        </div>
    </div>
</div>

<div class="background background--primary">
    <div class="container">
        <div class="row d-flex">
            <div class="col-sm-6 d-flex flex-column">
                <div class="flex-grow-1">
                    <h4 class="mt-0">Primary coding club</h4>
                    <p>
                        Download your FREE coding club pack for students aged 7-11. This pack introduces
                        students to the first principles of Python at a faster pace than the regular lesson
                        plans. It is aimed at students already interested in learning coding and can be used in clubs,
                        at home or in school, on or offline.
                    </p>
                    <p>
                        View the resources <a target="_blank" href="https://code-for-life.gitbook.io/code-for-life-primary-club-resources">online here</a>.
                    </p>
                </div>
                <div>
                    <a id="primary_pack" download type="submit" class="button button--primary button--icon" href="https://code-for-life.gitbook.io/code-for-life-primary-club-resources">
                        Download the Primary coding club pack<span class="iconify" data-icon="mdi:tray-arrow-down"></span>
                    </a>
                </div>
            </div>
            <div class="col-sm-6 d-flex flex-column">
                <div class="flex-grow-1">
                    <img title="Primary coding club" alt="Primary coding club" src="{% static 'portal/img/about_us_cfl.jpg' %}">
                </div>
            </div>
        </div>
    </div>
</div>


<div class="background">
    <div class="container">
        <div class="row d-flex">
            <div class="col-sm-6 d-flex flex-column">
                <div class="flex-grow-1">
                    <img title="Python coding club" alt="Python coding club" src="{% static 'portal/img/coding_club_python_pack.png' %}">
                </div>
            </div>
            <div class="col-sm-6 d-flex flex-column">
                <div class="flex-grow-1">
                    <h4 class="mt-0">Python coding club</h4>
                    <p>
                        Download your FREE coding club pack for students aged 12 and above.
                        This pack is a fast-paced introduction to Python. It is aimed at students already interested
                        in learning coding, individuals looking to learn and run their own club, or adults wanting to
                        try coding out. It is designed to be used in face-to-face or online clubs.
                    </p>
                    <p>
                        View the resources <a target="_blank" href="https://code-for-life.gitbook.io/code-for-life-python-club-resources">online here</a>.
                    </p>
                </div>
                <div>
                    <!-- TODO: improve responsiveness -->
                    <div style="margin-bottom: 10px;">
                        <a id="grass_snakes_pack" download class="button button--primary button--icon" href="https://content.gitbook.com/content/5508uzXa7roQPZikv2aI/blobs/kpNf9JheYqpbfjVWILfG/Grass%20Snakes%20Club.zip">
                            Lvl 1: Grass Snakes<span class="iconify" data-icon="mdi:tray-arrow-down"></span>
                        </a>
                    </div>
                    <div style="margin-bottom: 10px;">
                        <a id="tiger_snakes_pack" download type="submit" class="button button--primary button--icon" href="https://content.gitbook.com/content/5508uzXa7roQPZikv2aI/blobs/AwIiOPatP90PeCOwzaPX/Tiger%20Snakes%20Club.zip">
                            Lvl 2: Tiger Snakes<span class="iconify" data-icon="mdi:tray-arrow-down"></span>
                        </a>
                    </div>
                    <div>
                        <a id="cobra_snakes_pack" download type="submit" class="button button--primary button--icon" href="https://content.gitbook.com/content/5508uzXa7roQPZikv2aI/blobs/KLfkfRtnmPBaexhhtrPO/Cobra%20Club.zip">
                            Lvl 3: Cobra Snakes<span class="iconify" data-icon="mdi:tray-arrow-down"></span>
                        </a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

{% endblock content %}
