@import "partials/base";

@import "partials/banners";
@import "partials/buttons";
@import "partials/carousel";
@import "partials/footer";
@import "partials/forms";
@import "partials/grids";
@import "partials/header";
@import "partials/images";
@import "partials/popup";
@import "partials/progress-bars";
@import "partials/subnavs";
@import "partials/tables";
@import "partials/text";
@import "partials/ui-dialog";
@import "partials/utils";

.content-footer-wrapper {
  display: flex;
  flex-direction: column;
  min-height: 100vh;
  justify-content: space-between;

  @media (min-width: $desktop-small-min-width) {
    padding-top: $menu-height;
  }

  @media (min-width: $tablet-large-min-width) and (max-width: $tablet-large-max-width) {
    padding-top: $menu-height-xs;
  }
}
