ABOUT_BANNER = {
    "title": "About Code for Life",
    "subtitle": "Code For Life gives everyone the ability to shape technology’s future",
    "text": "",
    "image_class": "banner--picture--about",
}

GETINVOLVED_BANNER = {
    "title": "Get involved",
    "subtitle": "How you can get involved with the creation of Code for Life products and resources",
    "image_class": "banner--picture--getinvolved",
    "button": {
        "external": True,
        "text": "Opportunities with Code for Life",
        "link": "https://2662351606-files.gitbook.io/~/files/v0/b/gitbook-x-prod.appspot.com/o/spaces%2F-M_6UDUiGoJDhr_OXetO%2Fuploads%2FPavvCifcuUeZZZLkV01C%2FOpportunities%20with%20Code%20for%20Life.pdf?alt=media",
    },
}

CONTRIBUTE_BANNER = {
    "title": "Contribute to Code for Life",
    "subtitle": "How you can get involved with Code for Life products and resources and help us help others",
    "image_class": "banner--picture--contribute",
}
