@import "base";

body {
  color: $color-text-tertiary;
}

h1 {
  @include _font-size(60px);
  font-weight: 500;

  a,
  a:hover,
  a:active,
  a:visited,
  a:focus {
    color: $color-text-secondary;
    font-weight: 500;
  }
}

h2 {
  @include _font-size(55px);
  font-weight: 500;
}

h3 {
  @include _font-size(45px);
  font-weight: 500;
}

h4 {
  @include _font-size(30px);
  @include _margin(20px, 0px, 20px, 0px);
  font-weight: 500;
}

h5 {
  @include _font-size(24px);
  @include _margin(20px, 0px, 20px, 0px);
  font-weight: 500;
}

h6 {
  @include _font-size(20px);
  @include _margin(20px, 0px, 0px, 0px);
  font-weight: 500;
}

.subtitle1 {
  font-family: "Inter", sans-serif;
  @include _font-size(22px);
}

.subtitle2 {
  font-family: "Inter", sans-serif;
  @include _font-size(20px);
  font-weight: 500;
}

a {
  color: $color-text-tertiary;
  text-decoration: underline;
}

a:hover,
a:focus {
  color: $color-text-tertiary;
  text-decoration: underline;
  font-weight: 600;
}

.grid-benefits__text1 {
  grid-area: text1;
}

.grid-benefits__text2 {
  grid-area: text2;
}

.grid-benefits__text3 {
  grid-area: text3;
}

.grid-benefits__title {
  @include _padding(0px, 0px, 0px, 0px);
}

.grid-benefits__title1 {
  grid-area: title1;
}

.grid-benefits__title2 {
  grid-area: title2;
}

.grid-benefits__title3 {
  grid-area: title3;
}

p,
div#ot-sdk-cookie-policy {
  @include _padding(10px, 0px, 10px, 0px);
  margin: 0;
}

small {
  font-size: 80%;
}

blockquote {
  border-left: none;
  padding: 0;

  p {
    @include _font-size(20px);
    @include _line-height(25px);
    display: block;
    font-weight: lighter;
    text-align: right;

    &.says {
      font-family: "Space Grotesk", sans-serif;
      @include _font-size(24px);
      @include _line-height(30px);
      font-weight: 500;
      position: relative;
      text-align: left;
    }
  }
}

.text--brand-primary {
  color: $color-primary;
}

.text--brand-tertiary {
  color: $color-tertiary;
}

.semi-bold {
  font-weight: 500;
}
.content-header {
  @include _font-size(30px);
  @include _padding(10px, 0px, 10px, 0px);
  @include _margin(15px, 0px, 0px, 0px);
  letter-spacing: 1px;
  font-family: "Space Grotesk", sans-serif;
}

.content-header-primary {
  background-color: $color-primary;
  color: $color-text-secondary;
}

.content-header-secondary {
  background-color: $color-secondary;
  color: $color-text-primary;
}

.content-header-tertiary {
  background-color: $color-tertiary;
  color: $color-text-secondary;
}

.content-footer {
  background-color: $color-tertiary;
  color: $color-text-secondary;
  @include _padding(15px, 0px, 15px, 0px);
  @include _margin(20px, 0px, 0px, 0px);
}

.error-page {
  h2 {
    @include _margin(30px, 0px, 40px, 0px);
  }

  h5 {
    @include _margin(20px, 0px, 20px, 0px);
  }
}

.background--python-den {
  background-color: $color-background-python-den;
  color: $color-text-secondary;
}

@media (min-width: $tablet-small-min-width) {
  .list--two-columns {
    columns: 2;
  }
}

@media (min-width: $desktop-large-min-width) {
  html {
    font-size: 10px;
  }

  body {
    font-size: 18px;
  }
}

@media (min-width: $desktop-small-min-width) and (max-width: $desktop-small-max-width) {
  html {
    font-size: 9px;
  }

  body {
    font-size: 17px;
  }
}

@media (min-width: $tablet-large-min-width) and (max-width: $tablet-large-max-width) {
  html {
    font-size: 9px;
  }

  body {
    font-size: 16px;
  }
}

@media (min-width: $tablet-small-min-width) and (max-width: $tablet-small-max-width) {
  html {
    font-size: 8px;
  }

  body {
    font-size: 15px;
  }
}

@media (max-width: $mobile-max-width) {
  html {
    font-size: 7px;
  }

  body {
    font-size: 14px;
  }
}
