{% extends 'portal/base_no_userprofile.html' %}
{% load static %}

{% block css %}
<link rel="stylesheet" type="text/css" href='{% static "portal.css" %}'>
<link href="https://fonts.googleapis.com/css2?family=Space+Grotesk:wght@500&display=swap" rel="stylesheet">
<link href="https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600&display=swap" rel="stylesheet">
<link rel="shortcut icon" href="{% static 'portal/img/favicon.ico' %}" type="image/x-icon">
<link rel="icon" href="{% static 'portal/img/favicon.ico' %}" type="image/x-icon">
{% endblock css %}

{% block content %}
<div id="403_forbidden"></div>

<div class="error-page background container">
    <div class="row mx-0 d-flex justify-content-between">
        <div class="flex-grow-1">
            <h2>Oi!</h2>
            <h5>Kirsty says you're not allowed there.</h5>
            <p>Those pages belong to Kirsty. She won't let you in even if you ask nicely.</p>
            <a class="button button--primary" href="{% url 'home' %}">Back to homepage</a>
        </div>
        <img title="Kirsty" alt="Kirsty" src="{% static 'portal/img/kirsty.png' %}"/>
    </div>
</div>

{% endblock content %}
