<!-- copied from django-recaptcha 4.0.0 -->
{% include "django_recaptcha/includes/js_v2_invisible.html" %}
<div class="g-recaptcha"
    {% for name, value in widget.attrs.items %}{% if value is not False %} {{ name }}{% if value is not True %}="{{ value|stringformat:'s' }}"{% endif %}{% endif %}{% endfor %}
>
</div>
