{% extends 'portal/base.html' %}
{% load static %}
{% load app_tags %}

{% block subNav %}
<section class="banner banner--teacher">
    <h1 class="banner__text--primary">Terms of use</h1>
</section>
<div class="sticky-subnav sub-nav sub-nav--teacher">
    <ul class="nav is-flex" role="tablist">
        <li class="active"><a class="button button--secondary button--secondary--light" data-toggle="tab" href="#terms">Terms of use</a></li>
        <li><a class="button button--secondary button--secondary--light" data-toggle="tab" href="#terms-children">Child-friendly</a></li>
    </ul>
</div>
{% endblock subNav %}

{% block content %}
<div class="tab-content background container">
    <div id="terms" class="tab-pane active">
        <section><h4 id="terms-of-use">Terms of Use</h4></section>

        <ol class="list--two-columns">
            <li><p><a href="#introduction">Introduction</a></p></li>
            <li><p><a href="#registration-and-types-of-membership">Registration and Types of Membership</a></p></li>
            <li><p><a href="#misuse-of-code-for-life-site">Misuse of Code for Life site</a></p></li>
            <li><p><a href="#prohibitions">Prohibitions</a></p></li>
            <li><p><a href="#alerting-code-for-life">Alerting Code for Life</a></p></li>
            <li><p><a href="#intellectual-property">Intellectual Property</a></p></li>
            <li><p><a href="#our-liability">Our Liability</a></p></li>
            <li><p><a href="#miscellaneous">Miscellaneous</a></p></li>
        </ol>

        <hr>

        <h5 id="introduction">1. Introduction</h5>
        <div class="row d-flex">
            <div class="col-sm-6">
                <p>Ocado Innovation Limited (as &ldquo;Ocado Technology&rdquo;), the division that powers Ocado.com, the world&rsquo;s
                    largest online-only grocery retailer, has launched Code for Life. Code for Life is a nationwide
                    corporate social responsibility initiative to help support primary and secondary school teachers
                    deliver the new computer science curriculum. The aim of the initiative is to equip every child in
                    the country with the &ldquo;coding survival skills&rdquo; that will enable them to flourish in an increasingly
                    digital world.</p>
                <p>Ocado Innovation Limited is committed to protecting any data that we collect concerning you. By using
                    our services on this website you are agreeing to the use of the data that we collect in accordance
                    with the Privacy Notice and the Terms of Use (together, the &ldquo;Terms & Conditions&rdquo;), so please read
                    these carefully.</p>
            </div>
            <div class="col-sm-6">
                <p>Ocado Innovation Limited is committed to providing a valuable source of supporting materials for
                    teachers to deliver the current primary school curriculum, as well as a fun, educational web
                    application from which students can learn. The Terms & Conditions form a legal document which sets
                    out your rights and obligations, and those of Ocado Innovation Limited, a company registered in
                    England under registered company number 08813912 with its registered office at Buildings One & Two
                    Trident Place, Mosquito Way, Hatfield, Hertfordshire, United Kingdom, AL10 9UL (&ldquo;Ocado Innovation
                    Limited&rdquo;, &ldquo;we&rdquo;, &ldquo;our&rdquo; or &ldquo;us&rdquo; as appropriate in the context), in relation to the entire contents of
                    the Code for Life website and the games, platforms and other products or services offered by Ocado
                    Technology from time to time (collectively, &ldquo;Code for Life&rdquo;).</p>
            </div>
        </div>

        <hr>

        <div class="row d-flex">
            <div class="col-sm-6">
                <p><strong>Important: If you are under 13 years of age you must have your parent, guardian or carer&rsquo;s
                    consent to register for a Code for Life account, and to use their email address. If you are using
                    this at school, you must first have your teacher&rsquo;s permission to use this site. These Terms of Use
                    were most recently updated on {{ last_updated }}.</strong></p>
                <p>Code for Life includes all versions of &ldquo;Rapid Router&rdquo;, &ldquo;Python Den&rdquo;,
                    &ldquo;Kurono&rdquo; and any other games, platforms and other products or services released by us
                    (whether online or otherwise), from time to time, including all Code for Life websites used to play
                    the games, platforms and any other products or services that we make available.
                    &ldquo;Code for Life&rdquo;, &ldquo;Rapid Router&rdquo; and "&ldquo;Kurono&rdquo;" are registered UK trademarks of
                    Ocado Innovation Limited.</p>
                <p>You must take the time to read and understand the Terms of Use and the Privacy Notice before
                    registering for Code for Life.</p>
            </div>
            <div class="col-sm-6">
                <p><strong>By registering, you accept that you are entering into a contract with us in accordance with
                    the Terms & Conditions and the Privacy Notice. Visitors to the Code for Life portal who do not
                    register to become a User, similarly affirm that they are bound by the Terms & Conditions and the
                    Privacy Notice each time they access the Code for Life site. We reserve the right to update the
                    Terms of Use at any time, so please check them periodically, as all changes will be binding on you
                    provided that you use the website after they have been made. To assist you in determining whether
                    the Terms & Conditions have changed since your most recent visit to the website, we will display the
                    date when the Terms of Use and Privacy Notice were most recently updated.</strong></p>
                <p><strong>Important: You must ensure that any email address we hold for you is kept up-to-date and that
                    you have full access to it. Important notifications are sent to the email address you provide.
                    Failure to keep this information updated can result in your Code for Life account being deleted
                    and/or restricted.</strong></p>
            </div>
        </div>

        <hr>

        <h5 id="registration-and-types-of-membership">2. Registration and Types of Membership</h5>
        <p><strong>Membership falls into the following categories under the Agreement outlined in this notice:</strong></p>
        <ul>
            <li><p>Administrators: person or persons assigned responsibility for the management and security of
                membership by other Users;</p></li>
            <li><p>Users: any person using the Code for Life website, Rapid Router, Python Den, Kurono or any other game,
                application or platform of ours regardless of membership;</p></li>
            <li><p>Students: Users who are provided with login information for Code for Life by a teacher, parent,
                guardian or carer;</p></li>
            <li><p>Teachers; and</p></li>
            <li><p>Guardian, parents, carers.</p></li>
        </ul>
        <p>Many features of Code for Life require you to register as a User. Access to certain resources will be
            restricted from non-registered Users and Users who are not part of a participating school. Parents,
            guardians or carers of students registered through their school or club, should contact the child&rsquo;s teacher
            directly to request copies of the teaching resources, to assist with homework or progression in learning how
            to program. Teachers should provide a valid and professional email address when registering on the Code for
            Life site.</p>
        <p>If you register a school or club, you will automatically become the responsible ‘Administrator&rsquo;. You should
            provide a valid and professional email address when registering as a teacher. If you create a school on the
            Code for Life site, you, by default become an ‘Administrator&rsquo; for your school.</p>
        <p><strong>As an Administrator, you warrant that:</strong></p>
        <ul>
            <li><p>you are responsible and accountable for ensuring the online safety of the school or club for whom you
                are acting and that only legitimate institutional addresses should be accepted at sign up;</p></li>
            <li><p>all registration information you submit is accurate, complete and truthful;</p></li>
            <li><p>you will maintain the accuracy of such information; and</p></li>
            <li><p>if you are accepting the Terms & Conditions on behalf of a school or club, you have the authority to
                bind that institution, company or legal entity to the Terms & Conditions.</p></li>
        </ul>
        <p>The organisation Administrator is able to make other teachers in the organisation Administrators.</p>
        <p><strong>All Administrators should be aware that:</strong></p>
        <ul>
            <li><p>they are able to access all the classes, and the students of those classes, within the organisation.
                This also includes the students’ progress data, as well as any custom level created by colleagues or
                students within the organisation.</p></li>
            <li><p>they are able to manage (create, edit, transfer and remove) all the classes, students and levels
                within the organisation; and</p></li>
            <li><p>if there is only one Administrator in the organisation and that Administrator deletes their account,
                the Administrator role will automatically be transferred to the next Teacher in the organisation.
            </p></li>
        </ul>
        <p>As a User, you further warrant that you will only grant access codes to teachers, staff members and students
            who are current employees or students known to your school or club. Upon termination of a teacher or other
            staff member&rsquo;s employment with you, you will ensure they assign over all existing classes and/or students to
            another teacher within your school or club. If at any time you become aware of a User who falsely claims to
            be affiliated with your school or club, you are obliged to notify the Code for Life team immediately.</p>
        <p>A Code for Life User must not choose a username or institution name that could potentially infringe anyone&rsquo;s
            rights, which is intended to confuse, or which is offensive, hurtful or otherwise inappropriate, as
            reasonably determined by us. We reserve the right to change a username if we think it offends the Terms &
            Conditions. Users who are provided with login information for Code for Life by your teacher, parent,
            guardian or carer, are &ldquo;Students&rdquo;. Students are divided between those who are registered by a teacher
            through a school or club, or set up as an independent student using a parent, guardian, or carer email
            address.</p>
        <p>Please note that we are not an internet service provider. All Users of Code for Life must have internet
            access and the necessary software for email and web usage.</p>
        <p>Code for Life&rsquo;s Privacy Notice forms part of the Terms & Conditions, and your acceptance of the Terms &
            Conditions constitutes consent to the way we may handle your personal data as detailed in that notice.</p>

        <hr>

        <h5 id="misuse-of-code-for-life-site">3. Misuse of Code for Life site</h5>
        <p>We reserve the right (a) to suspend or terminate any User&rsquo;s access to Code for Life, or parts of it, and/or
            (b) to remove, or require the User to remove, material posted on Code for Life, if the User or material
            appears to us, or to someone who has complained to us, to be in breach of any provision of the Terms &
            Conditions.</p>
        <p>Any person whose access has been suspended or terminated may not re-register for, or re-access, the Code for
            Life portal without our prior written consent. You are responsible for everything which is done on or
            through the Code for Life portal through your registered email address(es) or whilst your Users account is
            logged on to the Code for Life site. In addition, we reserve the right to suspend or terminate any User&rsquo;s
            access to Code for Life, or parts of it, if the relevant User is abusive, discriminatory or threatening, or
            harasses or communicates offensive messages or images to another User; irrespective of whether this is done
            through the Code for Life site. </p>
        <p>We endeavour to ensure that the Code for Life website and access to your account and our games, platforms and
            other products or services are available 24 hours a day, but occasionally your access to the Code for Life
            website or to your account (including any old or live games or avatars) may be restricted to allow for
            repairs, maintenance or the introduction of new features or services. We aim to provide the best service
            possible, but we do not warrant that the Code for Life website, access to your account or any of the games,
            platforms or any of our other products or services (whether online or otherwise) will be fault, virus or
            error free. If you detect a problem or fault, please contact us using the
            <a class="freshdesk__contact-us">contact us form</a> and we will endeavour to correct the fault as quickly
            as we can. </p>
        <p>Notwithstanding any of the above, we reserve the right to decline any new registrations or suspend or cancel
            a User&rsquo;s account at any time and at our sole discretion (and without telling you beforehand), and we reserve
            the right to terminate your access to all or part of the games, platforms and other products or services
            that we make available from time to time (whether online or otherwise) which shall include any old or live
            games or avatar(s) you have created.</p>
        <p><strong>The Code for Life portal is intended to be used by its Users and Students for the purposes we
            describe in the Terms & Conditions and not for any other purposes. Accordingly, Users and Students must not:</strong></p>
        <ul>
            <li><p>place material on, or otherwise use, the Code for Life for any business or commercial purpose; or</p></li>
            <li><p>use their access to the Code for Life, or information gathered from it, in connection with the
                sending of unsolicited bulk email (sometimes known as spam).</p></li>
        </ul>

        <hr>

        <h5 id="prohibitions">4. Prohibitions</h5>
        <p>You must ensure that any activity and or communication through the Code for Life site, is not capable of (a)
            infringing the intellectual property or other rights of any person or entity, (b) breaching any applicable
            laws, regulations or codes of practice, whether criminal, tortuous or otherwise, (c) appearing to be
            offensive, harassing, threatening, harmful, vulgar, abusive, discriminatory, obscene, pornographic, false,
            libellous, defamatory, unreliable or misleading,  (d) being perceived as antisocial or disruptive, (e)
            gaining unauthorised access to other computer systems, (f) interfering with any other person&rsquo;s use or
            enjoyment of the Code for Life website or their account(s), or (g) engaging in any technically harmful
            behaviour, which includes but is not limited to, computer viruses, logic bombs, Trojan horses, worms,
            harmful components, corrupted data and other malicious software or harmful data.</p>

        <hr>

        <h5 id="alerting-code-for-life">5. Alerting Code for Life</h5>
        <p>If you see anything on the Code for Life portal which appears to infringe any part of the Terms & Conditions,
            then please inform us via the <a class="freshdesk__contact-us">Contact Us</a> section of this site.</p>
        <p>We do not endorse or take responsibility for the content of any third party sites that link to or from Code
            for Life.</p>

        <hr>

        <h5 id="intellectual-property">6. Intellectual Property</h5>
        <p>You acknowledge that all copyright, trademarks, and other intellectual property rights in and relating to
            Code for Life (including all content of the Code for Life website, the Rapid Router application, the Python Den
            application, the Kurono application, related software (including any drawn and/or animated avatars, whether or not such avatars have
            any modifications) and any other games, applications or any other content that we make available from time
            to time) are owned by Ocado Innovation Limited. These rights protect all of the applications, games,
            products and services you see on the Code for Life website from time to time, including the graphics of
            those games, their structure, gameplay and their &ldquo;look and feel&rdquo;. It is easy to copy material which appears
            on websites, but this does not mean it is legal. Therefore, no-one may copy, modify, distribute, show in
            public or create any derivative work from the Code for Life portal, or any part of the games or other
            material which is found on the Code for Life unless properly licensed to do so by us.</p>

        <hr>

        <h5 id="our-liability">7. Our Liability</h5>
        <p>The website, use of the application and games, and access to any accounts is provided by us on an &ldquo;as is&rdquo;
            basis without any warranties or guarantees. We do not accept responsibility for any errors, omissions, or
            for the results obtained from the use of such information or for any technical problems you may experience
            with the website.</p>
        <p>We shall not be liable for:</p>
        <ul>
            <li><p>any viruses or other disabling features that affect your access to or use of the website (including
                your account);</p></li>
            <li><p>incompatibility of the Code for Life website with any of your equipment, software or
                telecommunications links;</p></li>
            <li><p>delays or failures which you may experience whilst conducting any activity on the Code for Life
                website;</p></li>
            <li><p>technical problems including errors or interruptions of the Code for Life website;</p></li>
            <li><p>unsuitability, unreliability or inaccuracy of the Code for Life website, or the inadequacy of the
                Code for Life website to meet your requirements; or</p></li>
            <li><p>consequential or incidental damages (including but not limited to loss of revenue, loss of profits,
                loss of anticipated savings, wasted expenditure and loss of data) or any other indirect, special or
                punitive damages whatsoever that arise out of or are related to the Code for Life website.</p></li>
        </ul>
        <p>Nothing in the Terms & Conditions shall exclude or limit our liability for:</p>
        <ul>
            <li><p>death or personal injury caused by our negligence;</p></li>
            <li><p>fraud or fraudulent misrepresentation by us; or</p></li>
            <li><p>any liability which we cannot exclude or limit by law. </p></li>
        </ul>

        <hr>

        <h5 id="miscellaneous">8. Miscellaneous</h5>
        <p>The delay or failure of any party to exercise its rights provided for in these Terms & Conditions shall not
            be deemed a waiver of any further rights hereunder. If any provision of the Terms & Conditions is found to
            be unenforceable or invalid, that provision shall be limited or eliminated to the minimum extent necessary
            to enable the Terms & Conditions to remain in full force and effect. The Terms & Conditions shall be
            governed by and construed in accordance with the laws of England and Wales and the parties shall submit to
            the exclusive jurisdiction of the English courts.</p>
    </div>

    <div id="terms-children" class="tab-pane">

        <section><h4>Terms of Use</h4></section>

        <div class="row d-flex">
            <div class="col-sm-6">
                <p><strong>We ask that you take the time to read and understand our Terms of Use and the Privacy Notice
                    before registering for Code for Life. These Terms were last updated on {{ last_updated }}.
                </strong></p>
                <p>Our Terms of Use set out the rules that we ask you to follow when using Code for Life. The rules
                    cover:</p>
                <ul>
                    <li><p>all Code for Life websites used to play the games, platforms and any other products or
                        services that we make available to you</p></li>
                    <li><p>all versions of “Rapid Router”, “Python Den”, “Kurono” and any
                        other games, platforms and other products or
                        services we released (whether online or otherwise)</p></li>
                </ul>
                <p><strong>When you visit the Code for Life site or register with us you agree to follow these rules.</strong></p>
            </div>
            <div class="col-sm-6">
                <p><strong>We may need to update our Terms of Use every now and then. If you have registered with us
                    then we will email you to tell you about any changes we’ve made. We’ll also post a message up on the
                    site so that any visitors will know that our Terms have changed.  This page shows the date we last
                    made a change so you’ll always be able to check when the Terms were most recently updated.</strong></p>
                <p><strong>Important: Please make sure to keep your email address up to date as we will use this to send
                    you important messages about Code for Life. If you don’t keep it updated then it could lead to your
                    access being restricted or your account deleted.</strong></p>
                <p><strong>You should use the <a class="freshdesk__contact-us">Contact Us form</a> if you need help or
                    advice on how to use the site. Please be aware that we will never ask for personal information other
                    than what is required to identify your account and answer your questions, and we will never ask for
                    your password.</strong></p>
            </div>
        </div>

        <hr>

        <h5>1. Misuse of the Code for Life site</h5>

        <p>Please remember that you are responsible for everything you do when logged onto the Code for Life site. If
            you create content on Code for Life which we think breaks the rules of the Terms of Use then we may:</p>
        <ol type="a">
            <li><p>suspend or close your access Code for Life account, OR</p></li>
            <li><p>block your access to parts of the site OR</p></li>
            <li><p>remove (or ask you to remove) the post which we think broke the rules.</p></li>
        </ol>
        <p>If we have to suspend or close your account then you won’t be allowed to re-register or access the portal
            again unless we have given you our permission in writing to do so.</p>

        <p>We’ll do our best to make sure the Code for Life website and access to your account and our games, platforms
            and other products or services is available to you 24 hours a day. However, we sometimes have to limit
            users’ access to their account or the site so that we can make repairs or add new content.</p>

        <p>We also aim to provide you with the best service we can, but we can’t promise that the Code for Life site, or
            our games, platforms and services will always be fault, virus or mistake-free. If you notice a problem or
            fault, please let us know using the <a class="freshdesk__contact-us">contact us form</a> and we will do all
            we can to correct it as quickly as we can.</p>

        <p>Whether or not a user follows the Terms of Use we still have the right to:</p>
        <ol type="a">
            <li><p>choose whether to accept or reject their registration</p></li>
            <li><p>suspend and cancel their account at any time (without telling them first)</p></li>
            <li><p>stop them from accessing all or part of the games, platforms and any other of our services (including
                any old or live games or avatar(s) they’ve created).</p></li>
        </ol>

        <p><strong>The Code for Life portal was created to help you learn how to code, and this is the only purpose you
            should use it for. This means that you may not:</strong></p>
        <ul>
            <li><p>post content on Code for life for business purposes or use the Code for Life site for a business
                purpose OR</p></li>
            <li><p>use the Code for Life site or information you’ve taken from it, to send out spam emails.</p></li>
        </ul>

        <hr>

        <h5>2. Other limits of use</h5>

        <p>You must not:</p>
        <ol type="a">
            <li><p>copy content taken from our site or copy content created by another Code for Life user without
                permission,</p></li>
            <li><p>break any laws when using the site,</p></li>
            <li><p>create levels that contain offensive, threatening, harmful or false content,</p></li>
            <li><p>use the site in a way that causes disruption to other users,</p></li>
            <li><p>use the site in a way that helps someone to gain access to other computer systems that they do not
                have permission to access,</p></li>
            <li><p>use the site in a way that affects other peoples’ use or enjoyment of the Code for Life website,</p></li>
            <li><p>do anything that could cause damage the site, for example taking action that allows in, computer
                viruses, logic bombs, Trojan horses or some other kind of harmful software or data.</p></li>
        </ol>

        <hr>

        <h5>3. Alerting Code for Life</h5>

        <p>If you see anything on the Code for Life portal which you think breaks the rules in our Terms of Use, then
            please let us know by using the Contact Us section of the site.</p>

        <p>The Code for Life site has links to websites that are run by other organisations, and other organisation
            websites will sometimes have links to our site. We have no control over these other websites and so are not
            responsible for their contents.</p>

        <hr>

        <h5>4. Intellectual Property</h5>

        <p>The contents of the Code for Life website are our ‘Intellectual Property’. This means that you cannot copy or
            reuse them without our permission. Just because it is easy to copy some of the content on the website, this
            does not mean it is allowed. The content covered by Intellectual Property includes:</p>
        <ol type="a">
            <li><p>Rapid Router, Python Den and Kurono applications</p></li>
            <li><p>Games – this will include the design of the games (for example their graphics, style and gameplay)</p></li>
            <li><p>Avatars, whether they are drawn or animated</p></li>
            <li><p>Any other software or services you see on our website</p></li>
            <li><p>Source Code (this is the code that our website and games are made up of)</p></li>
        </ol>

        <hr>

        <h5>5. Our responsibilities</h5>

        <p>We will not be responsible for:</p>
        <ul>
            <li><p>viruses, trojans and similar threats that could affect your access to, or use of, the website
                (including your account),</p></li>
            <li><p>any problems you have logging on because your computer, mobile device, broadband or software won’
                work with our site,</p></li>
            <li><p>any delays or failures that happen when you are using the site,</p></li>
            <li><p>any errors loss of access to the site caused by a technical problem at Ocado,</p></li>
            <li><p>the site not being suitable for your learning needs,</p></li>
            <li><p>any inaccuracies in the description of our games or levels.</p></li>
        </ul>
    </div>
</div>

{% endblock content %}
