PLAY_BANNER = {
    "title": "Play",
    "subtitle": "Anyone can learn how to code. We will help you learn how. It’s " "fun, free and easy.",
    "text": "",
    "button": {"text": "Try Rapid Router", "link": "levels"},
    "button2": {"text": "Try Python Den", "link": "python_levels"},
    "image_class": "banner--picture--play",
    "alt": "Boy playing on ipad",
    "image_description": "Credit: Annie Spratt, Unsplash",
}

PLAY_HEADLINE = {
    "title": "Anyone can code, you can too!",
    "description": "Whether you’re a parent, teacher or a student, our games support "
    "and guide you, making learning to code great fun. Get started with Rapid Router "
    "designed for students new to coding. Rapid Router is where you will build up your "
    "ability.",
}
