{% extends 'portal/base.html' %}
{% load static %}
{% load app_tags %}

{% block subNav %}
<section class="banner banner--teacher">
    <h1 class="banner__text--primary">Privacy notice</h1>
</section>
<div class="sticky-subnav sub-nav sub-nav--teacher">
    <ul class="nav is-flex" role="tablist">
        <li class="active"><a id="privacy-notice-tab" class="button button--secondary button--secondary--light" data-toggle="tab" href="#privacy-notice">Privacy notice</a></li>
        <li><a class="button button--secondary button--secondary--light" data-toggle="tab" href="#privacy-children">Child-friendly</a></li>
    </ul>
</div>
{% endblock subNav %}

{% block content %}
<div class="tab-content background container">
    <div id="privacy-notice" class="tab-pane active">
        <p><strong>Last Updated: {{ last_updated }}</strong></p>
        <p>Please read this notice carefully. This notice contains important information on who manages the Code for Life
            portal, how and why we collect information about you (for example, your name and email address), how we use your
            information, and with which persons we share your information. We also explain what rights you have in relation
            to your personal information, for example, the right to say no to the use of your information in certain cases,
            and how to contact us if you want to find out more about your rights or if you have other questions about this
            notice.</p>
        <ol class="list--two-columns">
            <li><p><a href="#commitment">Our commitment</a></p></li>
            <li><p><a href="#who-we-are">Who we are</a></p></li>
            <li><p><a href="#types-of-information">Types of information we hold about you</a></p></li>
            <li><p><a href="#information-use">How we will use information about you</a></p></li>
            <li><p><a href="#change-of-purpose">Change of purpose</a></p></li>
            <li><p><a href="#cookies">Cookies</a></p></li>
            <li><p><a href="#third-parties">Sharing your personal information with other persons</a></p></li>
            <li><p><a href="#data-retention">How long will we keep your personal information?</a></p></li>
            <li><p><a href="#your-rights">Your rights</a></p></li>
            <li><p><a href="#security">Keeping your personal information secure</a></p></li>
            <li><p><a href="#how-to-complain">How to complain</a></p></li>
            <li><p><a href="#changes">Changes to this Privacy Notice</a></p></li>
            <li><p><a href="#contact-us">How to contact us</a></p></li>
            <li><p><a href="#extra-help">Do you need extra help?</a></p></li>
        </ol>

        <hr>

        <h5 id="commitment">1. Our commitment</h5>
        <p>We are deeply committed to creating a safe and secure online learning environment for all students, teachers,
            parents and guardians who use the Code for Life portal.</p>
        <ol>
            <li><p>We strive to give you control over the personal information that you give us, and we take the protection
                of your information very seriously.</p></li>
            <li><p>We take extra precautions for the safety and privacy of our younger learners. Where personal information
                could be entered, for example when a student names a level, the teacher is notified via email and the
                teacher has the ability to delete the level if its name is rude or compromising.</p></li>
            <li><p>Our portal only relates to Code for Life and we do not show advertisements on our website or within our
                lessons.</p></li>
        </ol>

        <hr>

        <h5 id="who-we-are">2. Who we are</h5>
        <p>We are a company called “Ocado Innovation Limited” or “Ocado Technology”, and we own the Code for Life learning
            portal. In this notice, we also use the name “Ocado” when we refer to us. Our office is at Buildings 1 & 2
            Trident Place, Hatfield Business Park, Mosquito Way, Hatfield, AL10 9UL.</p>
        <p>We are responsible for the personal information we collect about you on the Code for Life portal.</p>

        <hr>

        <h5 id="types-of-information">3. Types of information we hold about you</h5>
        <p>Your personal data, or personal information, is any information relating to you. It does not include anonymous
            information, which cannot be traced back to you or another person (anonymous data).</p>
        <p>When you use the Code for Life portal and our services we collect the following personal information:</p>

        <p>If you are a <strong>Student</strong>, we collect:</p>
        <ul>
            <li><p>Your name, password and class code: we collect this information when your teacher creates an account.</p></li>
            <li><p>Your school / club / teaching or education institution and your class code and class name, if you are a
                school Student: your Teacher provides this information to us.</p></li>
            <li><p>Performance information about your performance and progress (for example, what levels you have completed
                and what levels you create), and</p></li>
            <li><p>The coding you create (including any avatars you may create): we collect this information when you use
                the Code for Life portal.</p></li>
            <li><p>Your messages and queries you may send us: when you use the “Contact Us” form or email.</p></li>
            <li><p>When your account was created and when you last logged into your account: this information is generated
                at the time your account is created or you log in.</p></li>
            <li><p>Technical information about the device you use to access the Code for Life portal (e.g. device type
                and screen resolution), and technical information about how you use these (for example, which pages on
                our portal you visit, for how long you stay on each page, etc.): when you navigate the portal and allow
                the use of non-essential cookies.</p></li>
            <li><p>Data from Code for Life surveys you may take part in.</p></li>
        </ul>

        <p>If you are a <strong>Independent Student</strong>, we collect:</p>
        <ul>
            <li><p>Your name, email address and password: we collect this information when you create an account.</p></li>
            <li><p>Performance information about your performance and progress (for example, what levels you have completed
                and what levels you create), and</p></li>
            <li><p>The coding you create (including any avatars you may create): we collect this information when you use
                the Code for Life portal.</p></li>
            <li><p>Your messages and queries you may send us: when you use the “Contact Us” form or email.</p></li>
            <li><p>When you created an account and when you last logged in to your account: this information is generated at
                the time you create your account or log in.</p></li>
            <li><p>Technical information about the device you use to access the Code for Life portal (e.g. device type
                and screen resolution), and technical information about how you use these (for example, which pages on
                our portal you visit, for how long you stay on each page, etc.): when you navigate the portal and allow
                the use of non-essential cookies.</p></li>
            <li><p>Data from Code for Life surveys you may take part in.</p></li>
            <li><p>Your marketing preferences, if you select to sign up to our newsletter.</p></li>
            <li><p>If you are under 13 years old, we will collect the data of your parent or guardian as you will need to
                ask them to register on your behalf.</p></li>
        </ul>

        <p>If you are a <strong>Teacher</strong>, we collect:</p>
        <ul>
            <li><p>Your first and last names, email address and password: we collect this information when you create an
                account.</p></li>
            <li><p>Your school / club / teaching or educational institution, the classes you create, the students you
                register in each class, and the teachers you invite; also, any material you create: when you use the portal.</p></li>
            <li><p>Your messages and queries you may send us: when you use the “Contact Us” form or email.</p></li>
            <li><p>When you created an account and when you last logged in to your account: this information is generated at
                the time you create your account or log in.</p></li>
            <li><p>Technical information about the device you use to access the Code for Life portal (e.g. device type
                and screen resolution), and technical information about how you use these (for example, which pages on
                our portal you visit, for how long you stay on each page, etc.): when you navigate the portal and allow
                the use of non-essential cookies.</p></li>
            <li><p>Data from Code for Life surveys you may take part in.</p></li>
            <li><p>Your marketing preferences, if you select to sign up to our newsletter.</p></li>
        </ul>

        <p>If you are a <strong>Website visitor</strong>, we collect:</p>
        <ul>
            <li><p>Technical information about the device you use to access the Code for Life portal (e.g. device type
                and screen resolution), and technical information about how you use these (for example, which pages on
                our portal you visit, for how long you stay on each page, etc.): when you navigate the portal and allow
                the use of non-essential cookies.</p></li>
            <li><p>Your email address and marketing preferences, if you select to sign up to our newsletter.</p></li>
        </ul>

        <hr>

        <h5 id="information-use">4. How we will use information about you</h5>
        <p>We need all the categories of information that we describe above, so that we can:</p>
        <ul>
            <li><p>perform our agreement with you and provide you with our services. For example, to enable you to create an
                account and to access the portal and our learning materials. Having an account gives teachers access to
                course material, class and individual student management features, and also it gives students access to the
                portal in order to learn how to code within a supported environment (classroom), or independently (at home).</p></li>
            <li>fulfil our legitimate interests, such as our interests to:
                <ul>
                    <li><p>improve our services.</p></li>
                    <li><p>ensure that our portal is secure and is used in accordance with our Terms. For example, we may
                        use account information to limit a user temporarily or permanently from the Code for Life portal if
                        that user engages in inappropriate use of the site (e.g. giving other people access to their user
                        account, malicious misuse of the portal, including spam).</p></li>
                    <li><p>send you important information: for example, we use your email address to send you account
                        verification emails, emails to notify you about changes to our Terms, or about any maintenance
                        impacting your access to the portal. Sometimes, we may be required by law to send you this
                        information.</p></li>
                    <li><p>provide customer support and respond to your queries, for example, when you use the Contact Us
                        form. We strongly advise you not to disclose personal information (other than name and email
                        address) when contacting us – messages you exchange on the portal and any forms you submit to us
                        will be recorded. The Contact Us form is strictly for the purpose of user support. User-initiated
                        communication concerning topics other than those relating directly to the Code for Life portal,
                        including resources or user experience, may not be answered. Please be aware that we will never ask
                        for personal information other than what is required to identify your account and respond to your
                        queries, and we will never ask for your password.</p></li>
                    <li><p>protect our legal rights, for example, if we need to defend ourselves in court.</p></li>
                </ul>
            </li>
            <li><p>with your permission (or if you are under 13, the permission of the person who looks after you) to send
                you marketing communications (for example, our newsletter or communications about our portal features or
                upcoming events). You have the right to change your mind at any time (see the “Your Rights” section below
                for more information).</p></li>
            <li><p>with your permission (or if you are under 13, the permission of the person who looks after you), use
                cookies to collect information about how you use our portal, in order to analyse and improve user
                experience. This information is usually anonymised and used at an aggregate level. Please see section
                “Cookies” below for more information on what information we collect and how we use cookies.</p></li>
        </ul>

        <p>We summarise below the purposes for which we use your personal data and the lawful basis on which we rely.</p>

        <table class="table table-bordered header-primary">
            <tr>
                <th><strong>Purpose</strong></th>
                <th><strong>Legal basis</strong></th>
            </tr>
            <tr>
                <td><p>To allow you to create an account and provide our services to you through our portal, such as
                    providing course material and resources</p></td>
                <td><p>Contractual necessity: the information is necessary to fulfil our contract with you.</p></td>
            </tr>
            <tr>
                <td><p>To manage our relationship with you, including to allow you to manage your account, provide customer
                    support, to handle your requests and queries, to provide you with information about our services that
                    you use, or information about changes in our Terms or this Notice</p></td>
                <td>
                    <ul>
                        <li><p>Contractual necessity: to the extent the information is necessary to fulfil our contract with
                            you (e.g. to ensure that we provide to you the services that you have requested).
                        </p></li>
                        <li><p>Legitimate interests: to the extent the information is necessary to process queries and
                            effectively manage our relationship with you as user of our services.</p></li>
                        <li><p>Compliance with a legal obligation: to the extent we are required by law to contact you in
                            order to provide certain information (for example, to notify you of changes to our Terms)
                        </p></li>
                    </ul>
                </td>
            </tr>
            <tr>
                <td><p>To send you our newsletters and other promotional material about Code for Life</p></td>
                <td>
                    <ul>
                        <li><p>Your consent, where this is required by law.</p></li>
                        <li><p>Otherwise, when consent is not required, we will rely on our legitimate interest to keep you
                            informed of our services, to the extent this is permitted by law.</p></li>
                    </ul>
                </td>
            </tr>
            <tr>
                <td><p>To carry out analysis and compile statistics about the use of our portal, and the use of our
                    services, in order to enable us to provide a better service, feature and functionality</p></td>
                <td>
                    <ul>
                        <li><p>Your consent: where we obtain this information by using cookies.</p></li>
                        <li><p>Our legitimate interest to ensure the smooth and effective functioning of our portal and
                            services, to make sound business decisions about our services and to design, inform and deploy
                            our business strategies.</p></li>
                    </ul>
                </td>
            </tr>
            <tr>
                <td><p>To authenticate your account and to ensure the security of our portal, information systems and
                    assets, to monitor compliance with our Terms, to prevent illegal activities in relation to our services.</p></td>
                <td><p>Our legitimate interest to protect our business assets against illegal or inappropriate activities or
                    security threats and your legitimate interest to protect the security of your account and information.</p></td>
            </tr>
            <tr>
                <td><p>To protect our legal rights and to establish, exercise or defend legal claims relating to our
                    services.</p></td>
                <td><p>Our legitimate interest to protect our legal rights.</p></td>
            </tr>
            <tr>
                <td><p>For accounting, record keeping and audit purposes</p></td>
                <td><p>Our legitimate interest to effectively manage our business, audit our business processes and make
                    informed business decisions.</p></td>
            </tr>
        </table>

        <p>When we rely on <strong>legitimate interests</strong> to process personal data, we consider and balance those
            interests against any potential impact on you (both positive and negative) and your rights and interests. If we
            consider that our interests are overridden by the impact on you, we will not use your personal data in this way
            (unless the law gives us another valid ground to do so). You can obtain further information about how we assess
            our legitimate interests against any potential impact on you in respect of specific activities by contacting us.</p>

        <hr>

        <h5 id="change-of-purpose">5. Change of purpose</h5>
        <p>We will only use your personal information for the purposes for which we collected it or for other compatible
            purposes. If we need to use your personal information for an unrelated purpose, we will notify you and we will
            explain the basis on which we do so. Please note that we do not always need to rely on your consent to collect
            and process your personal information, and we will not seek your consent unless this is required by law.</p>

        <hr>

        <h5 id="cookies">6. Cookies</h5>
        <h6>6.1 What are Cookies?</h6>
        <p>Cookies are tiny files that have information (data) in them. When you visit our portal, a cookie is placed on
            the device you use. Cookies allow us to remember when you visit our portal, or when you open an email. They help
            us understand how you are using the Code for Life portal, as well as which parts of our portal are popular and
            which ones we need to make better.</p>
        <p>We also use other forms of technology (such as web beacons or pixels) which are similar to cookies and which
            allow us to monitor and improve our website. When we talk about cookies in this notice, we also refer to these
            technologies.</p>

        <h6>6.2 Types of cookies used</h6>
        <p>We use the following types of cookies on our portal for the following purposes:</p>

        <table class="table table-bordered header-primary">
            <tr>
                <th><strong>Types of cookies</strong></th>
                <th><strong>Purpose</strong></th>
                <th><strong>For how many months does the cookie stay on your browser?</strong></th>
            </tr>
            <tr>
                <td><p><u>Strictly necessary cookies</u></p></td>
                <td><p>These cookies do what you have asked for: for example, they allow the website to load on your
                    browser, they keep you logged in when you use our portal, and keep our portal safe. If you turn off
                    these cookies via your browser settings certain parts of the website will not function for you.</p>
                </td>
                <td><p>12</p></td>
            </tr>
            <tr>
                <td><p><u>Functional cookies</u></p></td>
                <td><p>These cookies enable the website to provide enhanced functionality and personalisation. If you do not
                    allow these cookies then some services may not function very smoothly. These kinds of cookies remember
                    things like your sound settings.</p>
                </td>
                <td><p>Session</p></td>
            </tr>
            <tr>
                <td><p><u>Analytics/Performance cookies</u></p></td>
                <td><p>These cookies help us understand how you use our portal and improve or optimise the experience we
                    provide. This can be anything like which pages you go to most often, and if you get error messages from
                    web pages. They allow us to measure how visitors interact with the portal (for example which parts of
                    the website are clicked on).</p>
                    <p>We use third-party web analytics software on our portal
                        (<a href="https://developers.google.com/analytics/devguides/collection/analyticsjs/cookie-usage" target="_blank">Google Analytics</a>).
                        We provide further information about these partners below.</p>
                </td>
                <td><p>24</p></td>
            </tr>
        </table>

        <h6 id="third-party-cookies">6.3 Third party cookies</h6>
        <p>We do not allow third party advertising, or affiliation on our portal.</p>
        <p>As we explain above, we work with other companies to use analytics cookies on our portal: these are Google, who
            provide Google Analytics cookies. We explain in more detail below what information they collect and how it is used.</p>
        <p><strong>Google Analytics</strong>. Our portal uses Google Analytics, which is provided by Google, Inc.
            ("Google"). Google Analytics uses cookies to help us analyse how users use our portal. The information generated
            by the cookie about your use of the website will be transmitted to and stored by Google on servers in the
            United States. Google will use this information for the purpose of evaluating your use of the website,
            compiling reports on website activity for website operators and providing other services relating to website
            activity and internet usage. Google may also transfer this information to third parties where required to do
            so by law, or where such third parties process the information on Google's behalf. <strong>Please note: since the
            release of Google Analytics 4, Google Analytics does not log or store IP addresses.</strong> You can read more about
            user data collection by Google Analytics 4 <a href="https://support.google.com/analytics/answer/12017362?hl=en"
                                                          target="_blank">here</a>.
            By accepting analytics / performance cookies on our portal, you consent to the processing of data about you
            by Google in the manner and for the purposes set out above.</p>

        <h6>6.4 Managing and disabling cookies</h6>
        <p>We make available a cookie management platform on our portal (provided by
            <a href="https://www.onetrust.com/" target="_blank">OneTrust</a>), through which you can turn off non-essential
            cookies at any time. Please note, strictly necessary cookies will always be set as they are essential for our
            website to operate.</p>
        <p>You can change your cookie preferences or withdraw consent by clicking on the following button:</p>

        <p>
            <!-- OneTrust Cookies Settings button start -->
            <button id="ot-sdk-btn" class="button button--primary optanon-toggle-display">Cookies Settings</button>
            <!-- OneTrust Cookies Settings button end -->
        </p>

        <hr>

        <h5 id="third-parties">7. Sharing your personal information with other persons</h5>
        <ul>
            <li><p>We share your personal information with our <strong>employees</strong>, to the extent this is necessary
                for them to perform their tasks, and with members of our group of companies, for the purposes set out in
                this Notice.</p></li>
            <li><p>We also share some limited information with third party <strong>service providers</strong> (as explained
                below) – these are companies that help us provide the portal to you, and they also help us to do all the
                actions that we describe in this Notice. When we trust our service providers with your information, we
                require them to respect the security of your personal data and to treat it in accordance with the law. We do
                not allow our third-party service providers to use your personal data for their own purposes and only permit
                them to process your personal information for specified purposes and in accordance with our instructions. We
                use the following types of service providers:</p></li>
        </ul>

        <h6>IT, email and web service providers</h6>
        <p>We share your personal information with our IT, email and web service providers, in order to enable them to
            provide us with their services. For example, we share your name and email address details with DotDigital, a
            service provider used for the purposes of sending emails to our users (such as  newsletters, collecting
            feedback, or any important service related emails). This data sharing enables us to send you emails, view when
            they are opened and view which links are clicked.</p>

        <h6>Surveys, support and feedback providers</h6>
        <p><strong>Freshdesk</strong> is our third party customer support tool that enables customers to contact us through
            a ticketing system on the website.</p>
        <p>For more information on Freshdesk’s Privacy Notice, visit
            <a href="https://www.freshworks.com/privacy/" target="_blank">https://www.freshworks.com/privacy/</a>.</p>
        <p>For more information on Freshdesk and GDPR, visit
            <a href="https://freshdesk.com/gdpr" target="_blank">https://freshdesk.com/gdpr</a>.</p>
        <p>We will occasionally ask for feedback on our portal. We will usually do this via an email which will direct you
            to our survey provider, <strong>UsabilityHub</strong>. It will only record; time spent, country, device type,
            device platform, unless specifically asked within the questions themselves for example, the survey may ask your
            age. You can find out more about UsabilityHub
            <a href="https://usabilityhub.com/" target="_blank">here</a>.</p>

        <ul>
            <li><p>If our business or part of our business is sold to another company, typically customer information would
                be transferred to that company. However, that company would still need to comply with this Privacy Notice
                and treat personal information as described in this Privacy Notice.</p></li>
            <li><p>Where necessary, we share personal information with our <strong>business advisors</strong>, such as legal
                advisors, consultants, accountants or auditors, for the purposes outlined in this Notice.</p></li>
            <li><p>In the event of a legal dispute, a court order or a legitimate request from a <strong>law enforcement
                agency or other public authority</strong>, we will share your personal information with our legal advisors,
                courts or such public authority, as necessary.</p></li>
        </ul>

        <hr>

        <h5 id="data-retention">8. How long will we keep your personal information?</h5>
        <p>We will only retain your personal information for as long as you have an active account, unless we need to retain
            this information for longer, after your account is deactivated, in order to protect our legal interests and
            establish, exercise or defend a legal claim. If you deactivate your account, we may anonymise your information
            and use it for a period of time in an anonymous format for research and other business purposes, such as
            business analytics.</p>
        <p>For users that have registered but whose accounts are inactive, we will delete your personal information after 3
            years of inactivity.</p>

        <hr>

        <h5 id="your-rights">9. Your rights</h5>
        <p>Under data protection laws, you have certain rights in relation to your personal information, which you can
            exercise free of charge. In summary, those include the right to:</p>
        <ul>
            <li><p>request a copy of your personal information and to certain other extra information that this Privacy
                Notice is already designed to address;</p></li>
            <li><p>require us to correct any mistakes in your information which we hold;</p></li>
            <li><p>require the erasure of personal information concerning you in certain situations;</p></li>
            <li><p>receive the personal information concerning you which you have provided to us, in a structured, commonly
                used and machine-readable format (e.g. in pdf or .csv format) and have the right to transmit those data to a
                third party in certain situations;</p></li>
            <li><p>object (say no) at any time to processing of personal information concerning you for direct marketing;</p></li>
            <li><p>object (say no) in certain other situations to our continued processing of your personal information;</p></li>
            <li><p>otherwise require us to only store but not use your personal information in certain circumstances;</p></li>
            <li><p>where you have given your permission for us to use your information, to change your mind at any time.</p></li>
        </ul>
        <p>Please note these rights may be <strong>limited</strong>, for example if fulfilling your request would reveal
            personal data about another person or if you ask us to delete information which we are required by law to keep
            or have compelling legitimate interests in keeping. We will inform you of the relevant exemptions upon which we
            rely when responding to any request you make.</p>
        <p>If you would like to exercise any of those rights, please:</p>
        <ul>
            <li><p>email our Data Protection Officer at
                <a href="mailto:individualrights@ocado.com">individualrights@ocado.com</a>;</p></li>
            <li><p>let us have enough information to identify you (e.g. username, full name and email address); and</p></li>
            <li><p>let us know (if possible) the information to which your request relates.</p></li>
        </ul>
        <p>If you would like to unsubscribe from any email newsletter or other promotional emails, you can click on the
            unsubscribe link which you can find at the bottom of our emails, in order to be removed from our mailing list.
            It could take up to 72 hours to process the update through our systems.</p>

        <hr>

        <h5 id="security">10. Keeping your personal information secure</h5>
        <p>We have security measures in place to prevent personal information from being accidentally lost, or used or
            accessed in an unauthorised way. We limit access to your personal information to those persons who have a
            genuine business need to know it and we require them to keep it confidential.</p>
        <p>We enable Teachers to use two-factor authentication to further reinforce the security of their accounts and we
            encourage them to do that. You can find more details
            <a href="https://www.getsafeonline.org/protecting-your-computer/passwords/" target="_blank">here</a>.</p>
        <p>If you want detailed information from Get Safe Online on how to protect your information and your computers and
            devices against fraud, identity theft, viruses and many other online problems, please visit
            <a href="https://www.getsafeonline.org" target="_blank">www.getsafeonline.org</a>. Get Safe Online is supported
            by HM Government and leading businesses.</p>

        <hr>

        <h5 id="how-to-complain">11. How to complain</h5>
        <p>We hope that we or our Data Protection Officer can resolve any query or concern you raise about this Privacy
            Notice or how we use your information.</p>
        <p>Alternatively, you also have the right to lodge a complaint with a data protection authority, in particular in
            the UK and/or the and/or the European Union (or European Economic Area) country  where you work, normally live
            or where any alleged infringement of data protection laws occurred. The data protection authority in the UK is
            the Information Commissioner who may be contacted at
            <a href="https://ico.org.uk/concerns/" target="_blank">https://ico.org.uk/concerns/</a> or telephone:
            +44 303 123 1113.</p>

        <hr>

        <h5 id="changes">12. Changes to this Privacy Notice</h5>
        <p>This Privacy Notice was last updated on {{ last_updated }}.</p>
        <p>We may change this Privacy Notice from time to time and you should check it regularly. If we make any material
            changes to this notice we will inform via appropriate means (e.g. email).</p>

        <hr>

        <h5 id="contact-us">13. How to contact us</h5>
        <p>Please contact our Data Protection Officer or us at
            <a href="mailto:individualrights@ocado.com">individualrights@ocado.com</a> if you have any questions about
            this Privacy Notice or the information we hold about you.</p>

        <hr>

        <h5 id="extra-help">14. Do you need extra help?</h5>
        <p>If you would like this Notice in another format (for example: audio, large print, braille) please contact us
            (see “How to contact us” above).</p>
    </div>

    <div id="privacy-children" class="tab-pane">
        <p><strong>Last Updated: {{ last_updated_children }}</strong></p>
        <p>This Privacy Notice will tell you what information we collect about you, how we use it, who we share it with,
            how long we keep it and how you can ask us about it.</p>
        <p>This is the version of the Privacy Notice without all the legal jargon (we understand how overly complicated
            some privacy policies can be!) A full version of the Privacy Notice can be found by clicking
            <a onclick="$('#privacy-notice-tab').click();">here</a>.</p>
        <p>What we mean by ‘personal information’ is any information that can be used to identify you, such as your name
            and email address.</p>

        <hr>

        <h5>1. Who we are</h5>

        <p>We are a company called “Ocado Innovation Limited” or “Ocado Technology”, and we run the Code for Life
            learning website. From now on in the Privacy Notice, we’ll just use the name “Ocado” to mean us. Our office
            is at Buildings 1 & 2 Trident Place, Hatfield Business Park, Mosquito Way, Hatfield, AL10 9UL, United
            Kingdom.</p>

        <hr>

        <h5>2. Personal information we collect about you</h5>

        <p>When you are signed up to a class <strong>by a teacher</strong> on our Code for Life website, we will collect
            the following personal information about you:</p>
        <ul>
            <li><p>Your name,</p></li>
            <li><p>Your password (this is encrypted which means we won’t be able to see the password you’ve chosen),</p></li>
            <li><p>Information about your performance and progress (for example, what levels you have completed and what
                levels you create),</p></li>
            <li><p>The code you’ve created on our website,</p></li>
            <li><p>Any messages you send us when you use the “Contact Us” form or email,</p></li>
            <li><p>The date your Code for Life account was created and the date you last logged in,</p></li>
            <li><p>Information about the device you use to visit the Code for Life site,</p></li>
            <li><p>Information about how you use the site, such as which pages you’ve visited and how long you stayed on
                each page. (We will only do this where you have allowed cookies – see the “Cookies and similar
                technologies” section for more details),
            </p></li>
        </ul>

        <p>If you sign up as an <strong>independent student</strong> for our Code for Life website, then we will also
            collect the following information about you:</p>
        <ul>
            <li><p>Your email address,</p></li>
            <li><p>The answers you give any Code for Life surveys you might fill in, although these are mostly
                anonymous,</p></li>
            <li><p>The marketing choices you have selected, if you are over 18 years of age and have signed up for our
                newsletter.</p></li>
        </ul>

        <p>If you are under 13 years old, you will need to ask a parent or guardian to register for you and we
            will collect personal information about them.</p>

        <hr>

        <h5>3. How we will use the information</h5>

        <p>The UK’s Data Protection rules say that we have to have a lawful reason to process your personal information
            (“lawful” meaning that the law allows us to use your information in that way).</p>
        <p>Below we’ve listed the lawful reasons which allow us to process your information for the Code of Life
            Website:</p>
        <p><strong>Contract:</strong> We have to collect some personal information about you so we can provide you with
            the services we offer on the Code for Life website. For example, we need your name and a password so you can
            create an account and access our website and learning materials. This means you can access the portal and
            learn how to code with the support of your teacher and classmates, or work on your own/with a guardian if
            you are an independent student.</p>
        <p><strong>Legitimate Interests:</strong> We collect personal information to:</p>
        <ul>
            <li><p>Help us improve the website and the services we can offer to you,</p></li>
            <li><p>Help make sure that our portal is safe and secure and that users are following our
                <a href="{% url 'terms'%}">Terms of Use</a>. For example, we might need to use account information to
                block a user from Code for Life temporarily or permanently if they misuse the site (e.g. by giving other
                people access to their account),</p></li>
            <li><p>If you are over 13, we need your email address to inform you about updates or changes to our service:
                for example, to let you know about any changes to our Terms of Use, or about any work we are carrying
                out that might affect when you can log on to the site. Sometimes, we may be required by law to send you
                this information,</p></li>
            <li><p>We will need to use your personal information to answer any questions you’ve asked using the ‘Contact
                Us’ form. Messages you send and receive through the site and any forms you send to us will be recorded.
                The Contact Us form is strictly for the purpose of user support. User-initiated communication concerning
                topics other than those relating directly to the Code for Life portal, including resources or user
                experience, may not be answered. Please be aware that we will never ask for personal information other
                than what is required to identify your account and respond to your queries, and we will never ask for
                your password,</p></li>
            <li><p>If you or your parent and guardian should make a legal claim against us, we may need to process your
                personal information to help defend ourselves against that claim.</p></li>
        </ul>

        <hr>

        <h5>4. Change of purpose</h5>

        <p>We will only use your personal information for the reasons we collected it or for other similar reasons. If
            we need to use your personal information for a different reason, we will tell you. We do not always need
            your consent to use your personal information, and we will not ask for your consent unless the law says we
            need it.</p>

        <hr>

        <h5>5. Cookies & Similar technologies</h5>

        <p>When you visit our website, it will leave small data files called Cookies (not the edible kind) on your
            computer. Some of these are needed for the site to work (e.g. to help to keep it secure). Others are there
            to remember your settings (like how you’ve set up the sound) for when you next visit. We also use cookies
            that collect information about how you use our website (e.g. what pages you visit and how long you spend on
            the site). This is so we can see which parts of our site are popular and which we can improve in future.</p>
        <p>Please see the “What are cookies” (not the edible kind!) section below for more information on what
            information we collect and how we use cookies.</p>

        <h6>What are cookies?</h6>

        <p>Cookies are tiny files that have information (data) in them. When you visit our site, we may put some cookies
            on the device you use. Cookies allow us to remember things like when you visit our site. They help us
            understand how you are using the Code for Life portal, as well as which parts of our portal are popular and
            which ones we need to make better.</p>
        <p>We also make use of things called “web beacons” or “pixels.” These are similar to cookies and allow us to
            keep an eye on how well our website is working and look for ways to improve it. To keep things simple, when
            we talk about cookies in this Privacy Notice, we also mean web beacons and pixels.</p>

        <h6>Types of cookies used</h6>

        <p>You can see all the different cookies we use and what we use them for below.</p>

        <table class="table table-bordered header-primary">
            <tr>
                <th><strong>Types of cookies</strong></th>
                <th><strong>Purpose</strong></th>
                <th><strong>How long does it stay on the browser?</strong></th>
            </tr>
            <tr>
                <td><p><u>Strictly necessary cookies</u></p></td>
                <td><p>These cookies do what you have asked for: for example, they allow the website to load on your
                    device, they keep you logged in when you use our site and help keep our site safe. If you turn off
                    these cookies using your browser settings, then it could stop some parts of the site from working.</p>
                </td>
                <td><p>12 months</p></td>
            </tr>
            <tr>
                <td><p><u>Functional cookies</u></p></td>
                <td><p>These cookies allow the website to remember your settings each time you revisit the site (for
                    example how you have your sound set up). If you do not allow these cookies, then some services may
                    not work as smoothly.</p>
                </td>
                <td><p>For as long as you are on the site</p></td>
            </tr>
            <tr>
                <td><p><u>Analytics/Performance cookies</u></p></td>
                <td><p>These cookies help us understand how you use our site, so we can improve the service we provide.
                    This can be anything like which pages you go to most often and if you get error messages from web
                    pages. They allow us to measure how visitors use the portal (for example which parts of the website
                    are clicked on and the length of time between clicks).</p>
                    <p>We use other companies called
                        (<a href="https://developers.google.com/analytics/devguides/collection/analyticsjs/cookie-usage" target="_blank">Google Analytics</a>)
                        to help us collect information from these cookies (see the “Third-party cookies” section below).</p>
                </td>
                <td><p>24 months</p></td>
            </tr>
        </table>

        <h6>Third party cookies</h6>

        <p>We work with other companies to run the analytics cookies on our portal, including Google, who provides our
            Google Analytics cookie. They might also collect information from websites that are not ours. We explain in
            more detail below what information they collect and how it is used. We do not let other companies show ads
            on our portal.</p>
        <p><strong>Google Analytics</strong>. We use Google Analytics (which is run by Google) to help us understand how
            you use our site. The information it collects about your use of the website will be stored by Google in the
            United States. Google Analytics does not collect IP addresses. Google may pass this information to other
            organisations who help them to interpret this information. They may also pass the information to other
            organisations if the law says they have to do so. If you choose to allow analytics / performance cookies on
            our site, you are consenting to Google using your data for the reasons above.</p>

        <h6>Managing and disabling cookies</h6>

        <p>You can switch the functional and analytics cookies on and off at any time by clicking this button below.</p>

        <p>
            <!-- OneTrust Cookies Settings button start -->
            <button id="ot-sdk-btn" class="button button--primary optanon-toggle-display">Cookies Settings</button>
            <!-- OneTrust Cookies Settings button end -->
        </p>

        <p>You cannot switch strictly necessary cookies off as our website won’t work properly without them.</p>

        <hr>

        <h5>6. Who might we share your personal information with?</h5>

        <p>Your personal information will be shared with the Code for Life Team in Ocado, so they can set up and run
            your account.</p>
        <p>We may also share a small amount of information with organisations that provide email services to help us run
            the Code for Life website.</p>
        <p>For example, we share your name and email address details with DotDigital, a company that sends emails to
            users on our behalf (such as when we want to collect your feedback or need to give you important email
            updates about our service). This data sharing also allows us to view when your emails have been opened.</p>
        <p>Another company we share personal data with is Freshdesk. They help us keep track of the questions users send
            using the Contact Us form, so we can reply to them more quickly.</p>
        <p>We also use a survey company called UsabilityHub to help us carry out surveys. UsabilityHub records time spent
             on the site, country, device type, device platform alongside any questions that we may ask you in our
             surveys (for example, the survey may ask your age). You can find out more about UsabilityHub
            <a href="https://usabilityhub.com/" target="_blank">here</a>.</p>
        <p>We’ll only share your personal information with organisations mentioned in this Privacy Notice. They all sign
            an agreement to say that they will keep your personal information as safe and secure as we do, and that they
            will strictly follow our instructions on how your data can be used.</p>
        <p>Finally, we may need to share your information for legal reasons, such as if we sold our business to another
            company, if our business advisors needed the information to help us achieve the purposes in this Privacy
            Notice, or to respond to law enforcement or court requests if there is a legal problem.</p>

        <hr>

        <h5>7. How long will we keep your personal data?</h5>

        <p>We’ll only retain your personal information for as long as you have an active account on Code for Life,
            unless we need to keep it for longer than this to help us defend a legal claim.</p>
        <p>Once you deactivate your account, we might keep an anonymous version of your information to help us with
            research and other business reasons like assessing how the business is performing and planning for the
            future.</p>
        <p>For users that have registered but whose accounts are inactive, we’ll delete your personal information after
            3 years of inactivity.</p>

        <hr>

        <h5>8. Your rights</h5>

        <p>Depending on where you live, you may have the rights to:</p>
        <ul>
            <li><p>ask us for a copy of the personal information we hold about you,</p></li>
            <li><p>have any mistakes in your personal information corrected,</p></li>
            <li><p>ask us to limit how we use your personal information,</p></li>
            <li><p>ask for your personal information to be deleted,</p></li>
            <li><p>ask us give copies of your personal data to another organisation,</p></li>
            <li><p>object (say no) to how we are using your personal information,</p></li>
            <li><p>ask us to store but not use your personal information,</p></li>
            <li><p>change your mind about giving us consent to use your personal data.</p></li>
        </ul>

        <p>If you would like to use any of these rights listed above, please email our Data Protection Officer at
            <a href="mailto:individualrights@ocado.com">individualrights@ocado.com</a>. Depending on where you live, you
            may need help from a parent or guardian to use your rights.</p>

        <hr>

        <h5>9. Keeping your information secure</h5>

        <p>Everyone at Ocado understands the need to keep your personal information safe so we’ve put steps in place to
            help prevent it from being accidentally lost or used in ways you wouldn’t expect.</p>
        <p>Only those people in Ocado who have a business need to know your personal information are allowed to have
            access to it, and they have to keep it confidential.</p>

        <hr>

        <h5>10. How to complain</h5>

        <p>If you have a complaint about how we’ve used your personal information, you can write to our Data Protection
            Officer at <a href="mailto:individualrights@ocado.com">individualrights@ocado.com</a>.</p>
        <p>You also have the right to complain to the Information Commissioner’s Office (the ICO). The ICO’s role is to
            make sure organisations like Ocado use your personal information fairly and keep it safe. You may contact
            the ICO by telephoning them on the number below or by visiting their website.</p>
        <p>Telephone: 0303 123 1113</p>
        <p>Website: <a href="https://ico.org.uk/concerns">https://ico.org.uk/concerns</a></p>

        <hr>

        <h5>11. Changes to the Privacy Notice</h5>

        <p>We may need to make changes to this Privacy Notice from time to time, so it’s a good idea to check it
            regularly. If we do ever change anything then we'll be sure to let you know (e.g. by sending you an email or
            posting an update on the Code for Life website).</p>

        <hr>

        <h5>12. How to contact us</h5>

        <p>Please contact our Data Protection Officer at <a href="mailto:individualrights@ocado.com">individualrights@ocado.com</a>
            if you have any questions about this Privacy Notice or the information we hold about you.</p>

        <hr>

        <h5>13. Do you need extra help?</h5>

        <p>If you would like this Privacy Notice in another format (for example, audio, large print, braille), please
            contact us (see the “How to contact us” section above).</p>
    </div>
</div>
{% endblock content %}
