{% extends 'portal/form_shapes.html' %}
{% load static %}

{% block form_content %}
    <div id="reset_password_done_page"></div>
    <h4>Your password has been reset</h4>
    <img class="background" title="Confirmation" alt="Confirmation tick" src="{% static 'portal/img/confirmation_tick.png' %}">
    <p>Please log in.</p>
    <div class="background">
        {% if usertype == "TEACHER" %}
            <a href="{% url 'teacher_login' %}" class="button button--primary button--login">OK</a>
        {% else %}
            <a href="{% url 'independent_student_login' %}" class="button button--home">OK</a>
        {% endif %}
    </div>
{% endblock form_content %}
