{% if module_name == "default" %}
    <!-- Production Environment -->
    <script>
        (function(w, d, s, l, i) {
        w[l] = w[l] || [];
        w[l].push({ "gtm.start": new Date().getTime(), event: "gtm.js" });
        var f = d.getElementsByTagName(s)[0],
            j = d.createElement(s),
            dl = l != "dataLayer" ? "&l=" + l : "";
        j.async = true;
        j.src = "https://www.googletagmanager.com/gtm.js?id=" + i + dl;
        f.parentNode.insertBefore(j, f);
        })(window, document, "script", "dataLayer", "GTM-M32M5N5");
    </script>
{% endif %}
{% if module_name == "staging" %}
    <!-- Staging environment -->
    <script>
        (function(w, d, s, l, i) {
        w[l] = w[l] || [];
        w[l].push({ "gtm.start": new Date().getTime(), event: "gtm.js" });
        var f = d.getElementsByTagName(s)[0],
            j = d.createElement(s),
            dl = l != "dataLayer" ? "&l=" + l : "";
        j.async = true;
        j.src =
            "https://www.googletagmanager.com/gtm.js?id=" +
            i +
            dl +
            "&gtm_auth=ZZqc7ZNE1mTX6vrV43Q_7g&gtm_preview=env-6&gtm_cookies_win=x";
        f.parentNode.insertBefore(j, f);
        })(window, document, "script", "dataLayer", "GTM-M32M5N5");
    </script>
{% endif %}
